@@ -15,7 +15,7 @@ memoize('compile_marc_path');
 memoize('parse_marc_spec');
 memoize('_get_index_range');
 
-our $VERSION = '1.281';
+our $VERSION = '1.32';
 
 sub marc_map {
     my $self = $_[0];
@@ -182,9 +182,24 @@ sub marc_add {
 
     if ( $marc_path =~ /^\w{3}$/ ) {
         my @field = ();
+
         push @field, $marc_path;
-        push @field, $subfields{ind1} // ' ';
-        push @field, $subfields{ind2} // ' ';
+
+        my $ind1 = $subfields{ind1} // ' ';
+        my $ind2 = $subfields{ind2} // ' ';
+
+        if ($ind1 =~ /^\$\.(\S+)$/) {
+            my $path = $1;
+            $ind1 = Catmandu::Util::data_at( $path, $data ); 
+        }
+
+        if ($ind2 =~ /^\$\.(\S+)$/) {
+            my $path = $1;
+            $ind2 = Catmandu::Util::data_at( $path, $data ); 
+        }
+       
+        push @field, $ind1;
+        push @field, $ind2;
 
         for ( my $i = 0; $i < @subfields; $i += 2 ) {
             my $code = $subfields[$i];
@@ -1041,7 +1056,7 @@ sub compile_marc_path {
     );
 
     my $MARC_PATH_REGEX
-        = qr/(\S{1,3})(\[([^,])?,?([^,])?\])?([\$_a-z0-9^-]+)?(\/([0-9]+)(-([0-9]+))?)?/;
+        = qr/(\S{1,3})(\[([^,])?,?([^,])?\])?([\$_a-zA-Z0-9^-]+)?(\/([0-9]+)(-([0-9]+))?)?/;
     if ( $marc_path =~ $MARC_PATH_REGEX ) {
         $field    = $1;
         $ind1     = $3;
